@@ -25,7 +25,7 @@ import requests
 
 from photini.configstore import key_store
 from photini.metadata import ImageMetadata
-from photini.photinimap import GeocoderBase, LatLongDisplay
+from photini.photinimap import GeocoderBase
 from photini.pyqt import *
 from photini.types import MD_Location
 from photini.widgets import CompactButton, LatLongDisplay, SingleLineEdit
@@ -146,11 +146,11 @@ class OpenCage(GeocoderBase):
         return MD_Location.from_address(address, self.address_map)
 
     def search_terms(self):
-        text = self.tr('Address lookup powered by OpenCage')
+        text = translate('AddressTab', 'Address lookup powered by OpenCage')
         tou_opencage = CompactButton(text)
         tou_opencage.clicked.connect(self.load_tou_opencage)
         tou_osm = CompactButton(
-            self.tr('Geodata © OpenStreetMap contributors'))
+            translate('AddressTab', 'Geodata © OpenStreetMap contributors'))
         tou_osm.clicked.connect(self.load_tou_osm)
         return [tou_opencage, tou_osm]
 
@@ -183,26 +183,24 @@ class LocationInfo(QtWidgets.QWidget):
             self.members[key].new_value.connect(self.editing_finished)
         self.members['CountryCode'].setMaximumWidth(
             width_for_text(self.members['CountryCode'], 'W' * 4))
-        self.members['SubLocation'].setToolTip('<p>' + translate(
-            'AddressTab', 'Enter the name of the sublocation.') + '</p>')
-        self.members['City'].setToolTip('<p>' + translate(
-            'AddressTab', 'Enter the name of the city.') + '</p>')
-        self.members['ProvinceState'].setToolTip('<p>' + translate(
-            'AddressTab', 'Enter the name of the province or state.') + '</p>')
-        self.members['CountryName'].setToolTip('<p>' + translate(
-            'AddressTab', 'Enter the name of the country.') + '<p>')
-        self.members['CountryCode'].setToolTip('<p>' + translate(
-            'AddressTab', 'Enter the 2 or 3 letter ISO 3166 country code'
-            ' of the country.') + '</p>')
-        self.members['WorldRegion'].setToolTip('<p>' + translate(
-            'AddressTab', 'Enter the name of the world region.') + '</p>')
-        for j, text in enumerate((
-                translate('AddressTab', 'Street'),
-                translate('AddressTab', 'City'),
-                translate('AddressTab', 'Province'),
-                translate('AddressTab', 'Country'),
-                translate('AddressTab', 'Region'),
-                )):
+        self.members['SubLocation'].setToolTip('<p>{}</p>'.format(translate(
+            'AddressTab', 'Enter the name of the sublocation.')))
+        self.members['City'].setToolTip('<p>{}</p>'.format(translate(
+            'AddressTab', 'Enter the name of the city.')))
+        self.members['ProvinceState'].setToolTip('<p>{}</p>'.format(translate(
+            'AddressTab', 'Enter the name of the province or state.')))
+        self.members['CountryName'].setToolTip('<p>{}</p>'.format(translate(
+            'AddressTab', 'Enter the name of the country.')))
+        self.members['CountryCode'].setToolTip('<p>{}</p>'.format(translate(
+            'AddressTab',
+            'Enter the 2 or 3 letter ISO 3166 country code of the country.')))
+        self.members['WorldRegion'].setToolTip('<p>{}</p>'.format(translate(
+            'AddressTab', 'Enter the name of the world region.')))
+        for j, text in enumerate((translate('AddressTab', 'Street'),
+                                  translate('AddressTab', 'City'),
+                                  translate('AddressTab', 'Province'),
+                                  translate('AddressTab', 'Country'),
+                                  translate('AddressTab', 'Region'))):
             label = QtWidgets.QLabel(text)
             label.setAlignment(Qt.AlignmentFlag.AlignRight)
             layout.addWidget(label, j, 0)
@@ -242,16 +240,15 @@ class TabWidget(QtWidgets.QWidget):
     def tab_name():
         return translate('AddressTab', '&Address')
 
-    def __init__(self, image_list, parent=None):
+    def __init__(self, parent=None):
         super(TabWidget, self).__init__(parent)
         self.app = QtWidgets.QApplication.instance()
         self.geocoder = OpenCage(parent=self)
-        self.image_list = image_list
         self.setLayout(QtWidgets.QHBoxLayout())
         ## left side
         left_side = QtWidgets.QGridLayout()
         # latitude & longitude
-        self.coords = LatLongDisplay(self.image_list)
+        self.coords = LatLongDisplay()
         left_side.addWidget(self.coords.label, 0, 0)
         self.coords.changed.connect(self.new_coords)
         left_side.addWidget(self.coords, 0, 1)
@@ -282,7 +279,7 @@ class TabWidget(QtWidgets.QWidget):
         self.layout().addWidget(self.location_info, stretch=1)
 
     def refresh(self):
-        self.new_selection(self.image_list.get_selected_images())
+        self.new_selection(self.app.image_list.get_selected_images())
 
     def do_not_close(self):
         return False
@@ -308,7 +305,7 @@ class TabWidget(QtWidgets.QWidget):
     @catch_all
     def duplicate_location(self):
         idx = self.location_info.currentIndex()
-        for image in self.image_list.get_selected_images():
+        for image in self.app.image_list.get_selected_images():
             # duplicate data
             location = MD_Location(self._get_location(image, idx) or {})
             # shuffle data up
@@ -322,7 +319,7 @@ class TabWidget(QtWidgets.QWidget):
     @catch_all
     def delete_location(self):
         idx = self.location_info.currentIndex()
-        for image in self.image_list.get_selected_images():
+        for image in self.app.image_list.get_selected_images():
             # shuffle data down
             location_list = list(image.metadata.location_shown or [])
             if idx == 0:
@@ -349,7 +346,7 @@ class TabWidget(QtWidgets.QWidget):
     def _location_tab_moved(self):
         idx_a, idx_b = self.pending_move
         # swap data
-        for image in self.image_list.get_selected_images():
+        for image in self.app.image_list.get_selected_images():
             temp_a = self._get_location(image, idx_a)
             temp_b = self._get_location(image, idx_b)
             self._set_location(image, idx_a, temp_b)
@@ -382,7 +379,7 @@ class TabWidget(QtWidgets.QWidget):
     @QtSlot(object, dict)
     @catch_all
     def new_location(self, widget, new_value, images=[]):
-        images = images or self.image_list.get_selected_images()
+        images = images or self.app.image_list.get_selected_images()
         idx = self.location_info.indexOf(widget)
         for image in images:
             temp = dict(self._get_location(image, idx) or {})
@@ -407,7 +404,7 @@ class TabWidget(QtWidgets.QWidget):
     @QtSlot()
     @catch_all
     def display_location(self):
-        images = self.image_list.get_selected_images()
+        images = self.app.image_list.get_selected_images()
         # get required number of tabs
         count = 0
         for image in images:
@@ -462,7 +459,7 @@ class TabWidget(QtWidgets.QWidget):
     @QtSlot()
     @catch_all
     def get_address(self):
-        images = self.image_list.get_selected_images()
+        images = self.app.image_list.get_selected_images()
         location = self.geocoder.get_address(self.coords.get_value())
         if location:
             self.new_location(
