@@ -32,7 +32,7 @@ except ImportError:
 
 from photini.metadata import Metadata
 from photini.pyqt import *
-from photini.pyqt import image_types_lower, video_types_lower
+from photini.pyqt import image_types_lower, qt_version_info, video_types_lower
 from photini.widgets import ComboBox, PushButton, StartStopButton
 
 logger = logging.getLogger(__name__)
@@ -271,19 +271,18 @@ class PathFormatValidator(QtGui.QValidator):
         return os.path.abspath(inp)
 
 
-class TabWidget(QtWidgets.QWidget):
+class ImporterTab(QtWidgets.QWidget):
     @staticmethod
     def tab_name():
         return translate('ImporterTab', '&Import photos')
 
-    def __init__(self, image_list, parent=None):
-        super(TabWidget, self).__init__(parent)
+    def __init__(self, parent=None):
+        super(ImporterTab, self).__init__(parent)
         self.app = QtWidgets.QApplication.instance()
         self.app.aboutToQuit.connect(self.stop_copy)
         if gp and self.app.options.test:
             self.gp_log = gp.check_result(gp.use_python_logging())
         self.config_store = self.app.config_store
-        self.image_list = image_list
         self.setLayout(QtWidgets.QGridLayout())
         form = FormLayout()
         self.nm = NameMangler()
@@ -362,7 +361,7 @@ class TabWidget(QtWidgets.QWidget):
         self.layout().addLayout(buttons, 0, 1, 2, 1)
         self.selection_changed()
         # final initialisation
-        self.image_list.sort_order_changed.connect(self.sort_file_list)
+        self.app.image_list.sort_order_changed.connect(self.sort_file_list)
         path = QtCore.QStandardPaths.writableLocation(
             QtCore.QStandardPaths.StandardLocation.PicturesLocation)
         self.path_format.setText(
@@ -581,8 +580,13 @@ class TabWidget(QtWidgets.QWidget):
     @catch_all
     def selection_changed(self):
         count = len(self.file_list_widget.selectedItems())
-        self.selected_count.setText(wrap_text(self.selected_count, translate(
-            'ImporterTab', '%n file(s) selected', '', count), 2))
+        if qt_version_info >= (6, 0):
+            # pyside6-lupdate doesn't recognise plurals with 'translate'
+            string = ImporterTab.tr('%n file(s) selected', '', count)
+        else:
+            # Qt5 doesn't handle ClassName.tr correctly
+            string = translate('ImporterTab', '%n file(s) selected', '', count)
+        self.selected_count.setText(wrap_text(self.selected_count, string, 2))
         if not self.file_copier:
             self.move_button.setEnabled(count > 0)
             self.copy_button.setEnabled(count > 0)
@@ -634,68 +638,69 @@ class TabWidget(QtWidgets.QWidget):
     @QtSlot()
     @catch_all
     def copy_selected(self, move=False):
-        copy_list = []
-        for item in self.file_list_widget.selectedItems():
-            name = item.data(Qt.ItemDataRole.UserRole)
-            info = self.file_data[name]
-            if (move and 'path' in info and
-                    self.image_list.get_image(info['path'])):
-                # don't rename an open file
-                logger.warning(
-                    'Please close image %s before moving it', info['name'])
+        with Busy():
+            copy_list = []
+            for item in self.file_list_widget.selectedItems():
+                name = item.data(Qt.ItemDataRole.UserRole)
+                info = self.file_data[name]
+                if (move and 'path' in info and
+                        self.app.image_list.get_image(info['path'])):
+                    # don't rename an open file
+                    logger.warning(
+                        'Please close image %s before moving it', info['name'])
+                else:
+                    copy_list.append(info)
+            if not copy_list:
+                return
+            if move:
+                self.move_button.set_checked(True)
+                self.copy_button.setEnabled(False)
             else:
-                copy_list.append(info)
-        if not copy_list:
-            return
-        if move:
-            self.move_button.set_checked(True)
-            self.copy_button.setEnabled(False)
-        else:
-            self.copy_button.set_checked(True)
-            self.move_button.setEnabled(False)
-        last_file_copied = None, datetime.min
-        copier_result = deque()
-        # start file copier in a separate thread
-        self.file_copier = FileCopier(
-            self.source, copy_list, move, copier_result)
-        copier_thread = QtCore.QThread(self)
-        self.file_copier.moveToThread(copier_thread)
-        copier_thread.started.connect(self.file_copier.start)
-        copier_thread.start()
-        # show files as they're copied
-        while self.file_copier.running:
-            if copier_result:
-                info, status = copier_result.popleft()
-                if not info:
-                    # copier thread has finished
-                    break
-                if status != 'ok':
-                    self._fail()
-                    break
-                if last_file_copied[1] < info['timestamp']:
-                    last_file_copied = info['dest_path'], info['timestamp']
-                for n in range(self.file_list_widget.count()):
-                    item = self.file_list_widget.item(n)
-                    if item.data(Qt.ItemDataRole.UserRole) == info['name']:
-                        item.setFlags(Qt.ItemFlag.NoItemFlags)
-                        self.file_list_widget.scrollToItem(
-                            item,
-                            self.file_list_widget.ScrollHint.PositionAtTop)
-                        self.selection_changed()
+                self.copy_button.set_checked(True)
+                self.move_button.setEnabled(False)
+            last_file_copied = None, datetime.min
+            copier_result = deque()
+            # start file copier in a separate thread
+            self.file_copier = FileCopier(
+                self.source, copy_list, move, copier_result)
+            copier_thread = QtCore.QThread(self)
+            self.file_copier.moveToThread(copier_thread)
+            copier_thread.started.connect(self.file_copier.start)
+            copier_thread.start()
+            # show files as they're copied
+            while self.file_copier.running:
+                if copier_result:
+                    info, status = copier_result.popleft()
+                    if not info:
+                        # copier thread has finished
                         break
-                self.image_list.open_file(info['dest_path'])
-            else:
-                # wait for copier result
-                self.app.processEvents()
-        self.move_button.set_checked(False)
-        self.copy_button.set_checked(False)
-        self.file_copier = None
-        copier_thread.quit()
-        copier_thread.wait()
+                    if status != 'ok':
+                        self._fail()
+                        break
+                    if last_file_copied[1] < info['timestamp']:
+                        last_file_copied = info['dest_path'], info['timestamp']
+                    for n in range(self.file_list_widget.count()):
+                        item = self.file_list_widget.item(n)
+                        if item.data(Qt.ItemDataRole.UserRole) == info['name']:
+                            item.setFlags(Qt.ItemFlag.NoItemFlags)
+                            self.file_list_widget.scrollToItem(
+                                item,
+                                self.file_list_widget.ScrollHint.PositionAtTop)
+                            self.selection_changed()
+                            break
+                    self.app.image_list.open_file(info['dest_path'])
+                else:
+                    # wait for copier result
+                    self.app.processEvents()
+            self.move_button.set_checked(False)
+            self.copy_button.set_checked(False)
+            self.file_copier = None
+            copier_thread.quit()
+            copier_thread.wait()
         if last_file_copied[0]:
             self.config_store.set(self.config_section, 'last_transfer',
                                   last_file_copied[1].isoformat(' '))
-            self.image_list.done_opening(last_file_copied[0])
+            self.app.image_list.done_opening(last_file_copied[0])
         self.list_files()
 
     @QtSlot()
@@ -703,3 +708,10 @@ class TabWidget(QtWidgets.QWidget):
     def stop_copy(self):
         if self.file_copier:
             self.file_copier.running = False
+            self.move_button.setEnabled(False)
+            self.copy_button.setEnabled(False)
+            self.app.processEvents()
+
+
+class TabWidget(ImporterTab):
+    pass
