@@ -121,14 +121,14 @@ class ImageMetadata(MetadataHandler):
             self.clear_group(tag, idx=idx)
 
     def clear_group(self, tag, idx=1):
-        for t in self._multi_tags[tag]:
-            sub_tag = t.format(idx=idx)
-            self.clear_value(sub_tag)
+        for sub_tag in self._multi_tags[tag]:
+            if sub_tag:
+                self.clear_value(sub_tag.format(idx=idx))
 
     def clear_value(self, tag):
-        if not (tag and self.has_tag(tag)):
-            return
-        self.clear_tag(tag)
+        {'Exif': self.clear_exif_tag,
+         'Iptc': self.clear_iptc_tag,
+         'Xmp': self.clear_xmp_tag}[tag.split('.')[0]](tag)
 
     def get_multi_group(self, tag):
         result = []
@@ -178,8 +178,7 @@ class ImageMetadata(MetadataHandler):
         try:
             return MD_Thumbnail.image_from_data(data)
         except Exception as ex:
-            logger.error(
-                '%s: %s: %s', os.path.basename(self._path), label, str(ex))
+            logger.error('%s: %s: %s', self._name, label, str(ex))
         return None, None
 
     def set_multi_group(self, tag, value):
@@ -194,7 +193,8 @@ class ImageMetadata(MetadataHandler):
 
     def set_group(self, tag, value, idx=1):
         for sub_tag, sub_value in zip(self._multi_tags[tag], value):
-            self.set_value(sub_tag, sub_value, idx=idx)
+            if sub_tag:
+                self.set_value(sub_tag, sub_value, idx=idx)
         if tag == 'Exif.Thumbnail.*' and value[3]:
             self.set_exif_thumbnail_from_buffer(value[3])
 
@@ -223,6 +223,8 @@ class ImageMetadata(MetadataHandler):
             self.clear_iptc()
         if not self.save_file():
             return False
+        if not self._path:
+            return True
         if file_times:
             os.utime(self._path, file_times)
         # check that data really was saved
@@ -241,11 +243,9 @@ class ImageMetadata(MetadataHandler):
                     'Canon', 'Casio', 'Fujif', 'Minol', 'Nikon', 'Olymp',
                     'Panas', 'Penta', 'Samsu', 'Sigma', 'Sony1'):
                 # maker note tags are often not saved
-                logger.warning(
-                    '%s: tag not saved: %s', os.path.basename(self._path), tag)
+                logger.warning('%s: tag not saved: %s', self._name, tag)
                 continue
-            logger.error(
-                '%s: tag not saved: %s', os.path.basename(self._path), tag)
+            logger.error('%s: tag not saved: %s', self._name, tag)
             OK = False
         return OK
 
@@ -377,6 +377,8 @@ class ImageMetadata(MetadataHandler):
     # WN (never). The order of the tags sets the precedence when values
     # conflict.
     _tag_list = {
+        'alt_text'       : (('WA', 'Xmp.iptc.AltTextAccessibility'),),
+        'alt_text_ext'   : (('WA', 'Xmp.iptc.ExtDescrAccessibility'),),
         'altitude'       : (('WA', 'Exif.GPSInfo.GPSAltitude*'),
                             ('WX', 'Xmp.exif.GPSAltitude*')),
         'aperture'       : (('WA', 'Exif.Photo.FNumber*'),
@@ -447,7 +449,6 @@ class ImageMetadata(MetadataHandler):
                             ('WN', 'Exif.Canon.LensModel*'),
                             ('WN', 'Exif.CanonCs.Lens*'),
                             ('WN', 'Exif.OlympusEq.LensModel*'),
-                            ('WN', 'Exif.OlympusEq.LensType'),
                             ('WN', 'Exif.Nikon3.Lens*'),
                             ('WN', 'Exif.NikonLd1.LensIDNumber*'),
                             ('WN', 'Exif.NikonLd2.LensIDNumber*'),
@@ -494,7 +495,7 @@ class ImageMetadata(MetadataHandler):
                 value = type_.from_exiv2(file_value, tag)
             except ValueError as ex:
                 logger.error('{}({}), {}: {}'.format(
-                    os.path.basename(self._path), name, tag, str(ex)))
+                    self._name, name, tag, str(ex)))
                 continue
             except Exception as ex:
                 logger.exception(ex)
@@ -537,7 +538,7 @@ class SidecarMetadata(ImageMetadata):
         if not path:
             return None
         try:
-            return cls(path)
+            return cls(path=path)
         except Exception as ex:
             logger.exception(ex)
             return None
@@ -547,7 +548,7 @@ class SidecarMetadata(ImageMetadata):
         sc_path = path + '.xmp'
         try:
             cls.create_sc(sc_path, image_md)
-            return cls(sc_path)
+            return cls(path=sc_path)
         except Exception as ex:
             logger.exception(ex)
             return None
@@ -568,6 +569,8 @@ class SidecarMetadata(ImageMetadata):
 class Metadata(object):
     # type of each Photini data field's data
     _data_type = {
+        'alt_text'       : MD_LangAlt,
+        'alt_text_ext'   : MD_LangAlt,
         'altitude'       : MD_Altitude,
         'aperture'       : MD_Aperture,
         'camera_model'   : MD_CameraModel,
@@ -616,12 +619,12 @@ class Metadata(object):
         # get maker note info
         if self._if:
             self._maker_note = {
-                'make': (self._if.has_tag('Exif.Photo.MakerNote') and
+                'make': (self._if.has_exif_tag('Exif.Photo.MakerNote') and
                          self._if.get_value('Exif.Image.Make')),
                 'delete': False,
                 }
         # read Photini metadata items
-        for name in self._data_type:
+        for name in ['timezone'] + list(self._data_type):
             # read data values from first file that has any
             values = []
             for handler in self._sc, video_md, self._if:
@@ -630,6 +633,16 @@ class Metadata(object):
                 values = handler.read(name, self._data_type[name])
                 if values:
                     break
+            # merge in camera timezone
+            if (name in ('date_digitised', 'date_modified', 'date_taken')
+                    and self.timezone):
+                for n, (tag, value) in enumerate(values):
+                    if not tag.startswith('Exif'):
+                        continue
+                    value = dict(value)
+                    value['tz_offset'] = self.timezone
+                    values[n] = (tag, self._data_type[name](value))
+                    logger.info('%s: merged camera timezone offset', tag)
             # choose result and merge in non-matching data so user can review it
             value = None
             if values:
@@ -639,18 +652,6 @@ class Metadata(object):
             for tag2, value2 in values[1:]:
                 value = value.merge(info, tag2, value2)
             super(Metadata, self).__setattr__(name, value)
-        # merge in camera timezone if needed
-        if not self.timezone:
-            return
-        for name in ('date_digitised', 'date_modified', 'date_taken'):
-            value = getattr(self, name)
-            if value['tz_offset'] is None:
-                value = dict(value)
-                value['tz_offset'] = self.timezone
-                info = '{}({})'.format(os.path.basename(self._path), name)
-                logger.info('%s: merged camera timezone offset', info)
-                super(Metadata, self).__setattr__(
-                    name, self._data_type[name](value))
 
     def find_sidecar(self):
         for base in (os.path.splitext(self._path)[0], self._path):
@@ -673,20 +674,15 @@ class Metadata(object):
         if self._if:
             self._maker_note['delete'] = True
 
-    @classmethod
-    def clone(cls, path, other):
-        if other._if:
-            # use exiv2 to clone image file metadata
-            other._if.save_file(path)
-        self = cls(path)
-        if other._sc and self._if:
-            # merge in sidecar data
-            self._if.merge_sc(other._sc)
-        # copy Photini metadata items
-        for name in cls._data_type:
-            value = getattr(other, name)
-            setattr(self, name, value)
-        return self
+    def clone(self, data):
+        image = ImageMetadata(buf=data)
+        if self._if:
+            image._image.setMetadata(self._if._image)
+        if self._sc:
+            image.merge_sc(self._sc)
+        if image.save_file():
+            data = bytes(image._image.io())
+        return data
 
     def _handler_save(self, handler, *arg, **kw):
         # store Photini metadata items
