@@ -19,16 +19,14 @@
 
 from datetime import datetime, timedelta
 from http.server import BaseHTTPRequestHandler, HTTPServer
-import imghdr
+import io
 import logging
 import os
 import re
-import shutil
 import threading
 import time
 import urllib
 
-import appdirs
 import keyring
 import requests
 
@@ -78,14 +76,17 @@ class UploadAborted(Exception):
 
 
 class AbortableFileReader(object):
-    def __init__(self, fileobj):
-        self._f = fileobj
+    def __init__(self, path=None, data=None):
+        if data:
+            self._f = io.BytesIO(data)
+            # requests library uses 'len' attribute instead of seeking to
+            # end of file and back
+            self.len = len(data)
+        else:
+            self._f = open(path, 'rb')
         # thread safe way to abort reading large file
         self._closing = threading.Event()
         self.abort = self._closing.set
-        # requests library uses 'len' attribute instead of seeking to
-        # end of file and back
-        self.len = os.fstat(self._f.fileno()).st_size
 
     # substitute read method
     def read(self, size):
@@ -95,6 +96,9 @@ class AbortableFileReader(object):
 
     # delegate all other attributes to file object
     def __getattr__(self, name):
+        if name == 'getvalue':
+            # don't allow requests library to suck in all data at once
+            raise AttributeError(name)
         return getattr(self._f, name)
 
 
@@ -123,24 +127,28 @@ class UploadWorker(QtCore.QObject):
                 'label': '{} ({}/{})'.format(
                      name, 1 + upload_count, len(self.upload_list)),
                 })
-            if convert:
-                path = convert(image)
-            else:
-                path = image.path
-            with open(path, 'rb') as f:
-                self.fileobj = AbortableFileReader(f)
-                try:
-                    error = session.do_upload(
-                        self.fileobj, imghdr.what(path), image, params)
-                except UploadAborted:
-                    error = 'UploadAborted'
-                    session.close_connection()
-                except Exception as ex:
-                    error = str(ex)
+            try:
+                if convert:
+                    data, image_type = convert(image)
+                    self.fileobj = AbortableFileReader(data=data)
+                else:
+                    image_type = image.file_type
+                    self.fileobj = AbortableFileReader(path=image.path)
+                error = session.do_upload(
+                    self.fileobj, image_type, image, params)
+            except UploadAborted:
+                error = 'UploadAborted'
+                session.close_connection()
+            except RuntimeError as ex:
+                error = str(ex)
+            except Exception as ex:
+                logger.exception(ex)
+                error = '{}: {}'.format(type(ex), str(ex))
+            finally:
+                if self.fileobj:
+                    self.fileobj.close()
             self.upload_progress.emit({'busy': False})
             self.fileobj = None
-            if convert:
-                os.unlink(path)
             if error:
                 if not session.api:
                     break
@@ -223,12 +231,11 @@ class AuthServer(QtCore.QObject):
 class PhotiniUploader(QtWidgets.QWidget):
     abort_upload = QtSignal(bool)
 
-    def __init__(self, image_list, *arg, **kw):
+    def __init__(self, *arg, **kw):
         super(PhotiniUploader, self).__init__(*arg, **kw)
         self.app = QtWidgets.QApplication.instance()
         self.app.aboutToQuit.connect(self.shutdown)
         self.logger.debug('using %s', keyring.get_keyring().__module__)
-        self.image_list = image_list
         self.setLayout(QtWidgets.QGridLayout())
         self.session = self.session_factory()
         self.session.connection_changed.connect(self.connection_changed)
@@ -277,8 +284,8 @@ class PhotiniUploader(QtWidgets.QWidget):
         group = QtWidgets.QGroupBox()
         group.setLayout(QtWidgets.QVBoxLayout())
         # list of albums widget
-        group.layout().addWidget(
-            QtWidgets.QLabel(translate('UploaderTabsAll', 'Add to albums')))
+        group.layout().addWidget(QtWidgets.QLabel(
+            translate('UploaderTabsAll', 'Add to albums')))
         scrollarea = QtWidgets.QScrollArea()
         scrollarea.setFrameStyle(scrollarea.Shape.NoFrame)
         scrollarea.setStyleSheet("QScrollArea {background-color: transparent}")
@@ -317,9 +324,6 @@ class PhotiniUploader(QtWidgets.QWidget):
         # initialise as not connected
         self.connection_changed(False)
 
-    def tr(self, *arg, **kw):
-        return QtCore.QCoreApplication.translate('UploaderTabsAll', *arg, **kw)
-
     @QtSlot()
     @catch_all
     def shutdown(self):
@@ -368,13 +372,13 @@ class PhotiniUploader(QtWidgets.QWidget):
         if not self.upload_worker:
             return False
         dialog = QtWidgets.QMessageBox(parent=self)
-        dialog.setWindowTitle(translate(
-            'UploaderTabsAll', 'Photini: upload in progress'))
+        dialog.setWindowTitle(
+            translate('UploaderTabsAll', 'Photini: upload in progress'))
         dialog.setText('<h3>{}</h3>'.format(translate(
             'UploaderTabsAll',
             'Upload to {} has not finished.').format(self.service_name)))
-        dialog.setInformativeText(
-            translate('UploaderTabsAll', 'Closing now will terminate the upload.'))
+        dialog.setInformativeText(translate(
+            'UploaderTabsAll', 'Closing now will terminate the upload.'))
         dialog.setIcon(dialog.Icon.Warning)
         dialog.setStandardButtons(
             dialog.StandardButton.Close | dialog.StandardButton.Cancel)
@@ -397,31 +401,26 @@ class PhotiniUploader(QtWidgets.QWidget):
             pixmap.loadFromData(picture)
         self.user_photo.setPixmap(pixmap)
 
-    def get_temp_filename(self, image, ext='.jpg'):
-        temp_dir = os.path.join(appdirs.user_cache_dir('photini'), 'uploader')
-        if not os.path.isdir(temp_dir):
-            os.makedirs(temp_dir)
-        return os.path.join(temp_dir, os.path.basename(image.path) + ext)
-
-    def copy_metadata(self, image, path):
-        # copy metadata
-        md = Metadata.clone(path, image.metadata)
-        # save metadata
-        md.dirty = True
-        md.save(if_mode=True, sc_mode='none', iptc_mode='preserve')
-
     def convert_to_jpeg(self, image):
-        im = QtGui.QImage(image.path)
-        path = self.get_temp_filename(image)
-        im.save(path, format='jpeg', quality=95)
-        self.copy_metadata(image, path)
-        return path
+        reader = QtGui.QImageReader(image.path)
+        im = reader.read()
+        if not im or im.isNull():
+            raise RuntimeError(
+                '{}: {}'.format(image.path, reader.errorString()))
+        buf = QtCore.QBuffer()
+        buf.open(buf.OpenModeFlag.WriteOnly)
+        im.save(buf, format='jpeg', quality=95)
+        data = buf.data().data()
+        # copy metadata
+        data = image.metadata.clone(data)
+        return data, 'image/jpeg'
 
     def copy_file_and_metadata(self, image):
-        path = self.get_temp_filename(image, ext='')
-        shutil.copyfile(image.path, path)
-        self.copy_metadata(image, path)
-        return path
+        with open(image.path, 'rb') as f:
+            data = f.read()
+        # copy metadata
+        data = image.metadata.clone(data)
+        return data, image.file_type
 
     def is_convertible(self, image):
         if not image.file_type.startswith('image'):
@@ -448,26 +447,24 @@ class PhotiniUploader(QtWidgets.QWidget):
         dialog = QtWidgets.QMessageBox(parent=self)
         if not self.is_convertible(image):
             msg = translate(
-                'UploaderTabsAll',
-                'File "{0}" is of type "{1}", which {2} does not' +
-                ' accept and Photini cannot convert.')
+                'UploaderTabsAll', 'File "{0}" is of type "{1}", which {2}'
+                ' does not accept and Photini cannot convert.')
             buttons = dialog.StandardButton.Ignore
         elif self.rejected_file_type(image.file_type):
             msg = translate(
-                'UploaderTabsAll',
-                'File "{0}" is of type "{1}", which {2} does not' +
-                ' accept. Would you like to convert it to JPEG?')
+                'UploaderTabsAll', 'File "{0}" is of type "{1}", which {2}'
+                ' does not accept. Would you like to convert it to JPEG?')
             buttons = dialog.StandardButton.Yes | dialog.StandardButton.Ignore
         else:
             msg = translate(
-                'UploaderTabsAll',
-                'File "{0}" is of type "{1}", which {2} may not' +
-                ' handle correctly. Would you like to convert it to JPEG?')
+                'UploaderTabsAll', 'File "{0}" is of type "{1}", which {2}'
+                ' may not handle correctly. Would you like to convert it'
+                ' to JPEG?')
             buttons = dialog.StandardButton.Yes | dialog.StandardButton.No
-        dialog.setWindowTitle(
-            translate('UploaderTabsAll', 'Photini: incompatible type'))
-        dialog.setText('<h3>{}</h3>'.format(
-            translate('UploaderTabsAll', 'Incompatible image type.')))
+        dialog.setWindowTitle(translate(
+            'UploaderTabsAll', 'Photini: incompatible type'))
+        dialog.setText('<h3>{}</h3>'.format(translate(
+            'UploaderTabsAll', 'Incompatible image type.')))
         dialog.setInformativeText(msg.format(os.path.basename(image.path),
                                              image.file_type, self.service_name))
         dialog.setIcon(dialog.Icon.Warning)
@@ -488,11 +485,11 @@ class PhotiniUploader(QtWidgets.QWidget):
     @QtSlot()
     @catch_all
     def start_upload(self):
-        if not self.image_list.unsaved_files_dialog(with_discard=False):
+        if not self.app.image_list.unsaved_files_dialog(with_discard=False):
             return
         # make list of items to upload
         upload_list = []
-        for image in self.image_list.get_selected_images():
+        for image in self.app.image_list.get_selected_images():
             params = self.get_upload_params(image)
             if not params:
                 continue
@@ -545,15 +542,15 @@ class PhotiniUploader(QtWidgets.QWidget):
                     width_for_text(self.progress_label, 'X' * 20))
                 self.progress_label.setText(elided)
             else:
-                self.progress_label.setText(translate(
-                    'UploaderTabsAll', 'Progress'))
+                self.progress_label.setText(
+                    translate('UploaderTabsAll', 'Progress'))
 
     @QtSlot(str, str)
     @catch_all
     def upload_error(self, name, error):
         dialog = QtWidgets.QMessageBox(self)
-        dialog.setWindowTitle(translate(
-            'UploaderTabsAll', 'Photini: upload error'))
+        dialog.setWindowTitle(
+            translate('UploaderTabsAll', 'Photini: upload error'))
         dialog.setText('<h3>{}</h3>'.format(translate(
             'UploaderTabsAll', 'File "{}" upload failed.').format(name)))
         dialog.setInformativeText(error)
@@ -620,8 +617,8 @@ class PhotiniUploader(QtWidgets.QWidget):
             return
         # wait for user to authorise in web browser
         dialog = QtWidgets.QMessageBox(self)
-        dialog.setWindowTitle(translate(
-            'UploaderTabsAll', 'Photini: authorise'))
+        dialog.setWindowTitle(
+            translate('UploaderTabsAll', 'Photini: authorise'))
         dialog.setText('<h3>{}</h3>'.format(translate(
             'UploaderTabsAll', 'Authorisation required')))
         dialog.setInformativeText(translate(
@@ -652,7 +649,7 @@ class PhotiniUploader(QtWidgets.QWidget):
             self.buttons['upload'].setEnabled(False)
             return
         if selection is None:
-            selection = self.image_list.get_selected_images()
+            selection = self.app.image_list.get_selected_images()
         self.buttons['upload'].setEnabled(len(selection) > 0)
         if 'sync' in self.buttons:
             self.buttons['sync'].setEnabled(
@@ -687,7 +684,7 @@ class PhotiniUploader(QtWidgets.QWidget):
                 params['meta']['title'] = image.name
             description = []
             if image.metadata.headline:
-                description.append(str(image.metadata.headline))
+                description.append(image.metadata.headline)
             if image.metadata.description:
                 description.append(image.metadata.description.default_text())
             if description:
@@ -878,7 +875,7 @@ class PhotiniUploader(QtWidgets.QWidget):
             # make list of known photo ids
             photo_ids = {}
             unknowns = []
-            for image in self.image_list.get_selected_images():
+            for image in self.app.image_list.get_selected_images():
                 for keyword in image.metadata.keywords or []:
                     photo_id = self.uploaded_id(keyword)
                     if photo_id:
